function [X_c Y_c X_s Y_s] = NACA(NACAnum,varargin)
%NACA Determines ordinates for 4-series, 5-series, and 6-series NACA
%airfoils.
    %NACA(STRING) returns ordinates for the airfoil described by STRING.
    %For example, if STRING = '2412'; then NACA will determine ordinates for
    %the 2412 airfoil, assuming a unit chord length and zero angle of
    %incidence.
    
    %NACA(STRING,CHORD) allows the user to specify the chord length.
    
    %NACA(STRING,CHORD,AOI) allows the user to specify chord length and
    %angle of incidence [radians].

%calculate ordinates
n=length(NACAnum);
x=0:.001:1;
switch n
    case 4 %4 digit airfoil
        %interpret string data
        m=(1/100)*str2double(NACAnum(1));
        p=(1/10)*str2double(NACAnum(2));
        T=(1/100)*str2double(NACAnum(3:4));
        
        %define constants
        a0=.2969;
        a1=-.1260;
        a2=-.3516;
        a3=.2843;
        a4=-.1015;
        
        %mean camber line
        x1=x(x<p);
        x2=x(x>=p);
        y_c=zeros(1,length(x));
        y_c(x<p)=(m/p^2)*(2*p*x1-x1.^2);
        y_c(x>=p)=(m/(1-p).^2)*(1-2*p+2*p*x2-x2.^2);
        
        %airfoil thickness w.r.t mean camber line
        y_t=(T/.2)*(a0*x.^.5 + a1*x + a2*x.^2 + a3*x.^3 + a4*x.^4);
        
        %slope of mean camber line
        dyc_dx(x<p)=((2*m)/(p.^2))*(p-x1);
        dyc_dx(x>=p)=((2*m)/(1-p).^2)*(p-x2);
        theta=atan(dyc_dx);
        
        %upper and lower surfaces
        x_u=x-y_t.*sin(theta);
        y_u=y_c+y_t.*cos(theta);
        x_l=x+y_t.*sin(theta);
        y_l=y_c-y_t.*cos(theta);
        
        %combine upper and lower surfaces into one vector
        x_u=fliplr(x_u);
        y_u=fliplr(y_u);
        x_s=[x_l x_u];
        y_s=[y_l y_u];
    case 5 %5 digit airfoil
        %interpret string data
        C_L=.15*str2double(NACAnum(1));
        m=5*str2double(NACAnum(2));
        sr=str2double(NACAnum(3));
        xx=str2double(NACAnum(4:5));
        
    case 6 %6 digit airfoil
end

%alter ordinates for chord length and AOI
switch nargin
    case 1
        %output
        X_c=x;
        Y_c=y_c;
        X_s=x_s;
        Y_s=y_s;
    case 2 %chord length
        chord=varargin{1};
        
        %scale up airfoil by chord factor
        X_c=chord*x;
        Y_c=chord*y_c;
        X_s=chord*x_s;
        Y_s=chord*y_s;
    case 3 %rotation angle and chord length
        chord=varargin{1};
        theta=varargin{2};
        
        %scale up airfoil by chord factor
        x=chord*x;
        y_c=chord*y_c;
        x_s=chord*x_s;
        y_s=chord*y_s;
        
        %use rotation matrix operation to rotate around (0,0)
        [x y_c]=rotate([x' y_c'],(theta*pi)/180);
        [x_s y_s]=rotate([x_s' y_s'],(theta*pi)/180);
        
        %output
        X_c=x;
        Y_c=y_c;
        X_s=x_s;
        Y_s=y_s;
end

